<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Annotation;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Apigee X/Hybrid authentication annotation.
 *
 * @Annotation
 */
final class ApigeeXAuth extends ApigeeAuth {

  /**
   * Constructs a new object.
   *
   * @param array $values
   *   Array of values.
   */
  public function __construct(array $values) {
    $values = NestedArray::mergeDeep([
      'multivalue' => [
        'fields' => [
          'endpoint' => [
            // This is not required because there is a default value which
            // is the only valid value for now.
            'required' => FALSE,
          ],
          'service_account_key' => [
            'label' => new TranslatableMarkup('GCP service account key'),
            'required' => TRUE,
          ],
        ],
      ],
    ], $values);
    parent::__construct($values);
  }

}
